@@ -5,7 +5,10 @@ test_that("print.draws_matrix runs without errors", {
   )
 
   x <- weight_draws(x, rep(1, ndraws(x)))
-  expect_output(print(x), "hidden reserved variables \\{'\\.log_weight'\\}")
+  expect_output(
+    print(x),
+    "hidden reserved variables ..\\.log_weight.."
+  )
 })
 
 test_that("print.draws_array runs without errors", {
@@ -15,7 +18,10 @@ test_that("print.draws_array runs without errors", {
   )
 
   x <- weight_draws(x, rep(1, ndraws(x)))
-  expect_output(print(x), "hidden reserved variables \\{'\\.log_weight'\\}")
+  expect_output(
+    print(x),
+    "hidden reserved variables ..\\.log_weight.."
+  )
 })
 
 test_that("print.draws_df runs without errors", {
@@ -39,17 +45,26 @@ test_that("print.draws_list runs without errors", {
   )
 
   x <- weight_draws(x, rep(1, ndraws(x)))
-  expect_output(print(x), "hidden reserved variables \\{'\\.log_weight'\\}")
+  expect_output(
+    print(x),
+    "hidden reserved variables ..\\.log_weight.."
+  )
 })
 
 test_that("print.draws_rvars runs without errors", {
+  skip_on_os("windows")
   x <- as_draws_rvars(example_draws())
-  expect_output(print(x),
-    "A draws_rvars: 100 iterations, 4 chains, and 3 variables"
+  expect_output(
+    print(x),
+    "A draws_rvars: 100 iterations, 4 chains, and 3 variables",
+    fixed = TRUE
   )
 
   x <- weight_draws(x, rep(1, ndraws(x)))
-  expect_output(print(x), "hidden reserved variables \\{'\\.log_weight'\\}")
+  expect_output(
+    print(x),
+    "hidden reserved variables ..\\.log_weight.."
+  )
 })
 
 test_that("print.draws_array handles reserved variables correctly", {
@@ -58,8 +73,7 @@ test_that("print.draws_array handles reserved variables correctly", {
   expect_output(print(x, max_variables = 1), "variable = tau")
   expect_output(
     print(x),
-    "hidden reserved variables {'.log_weight'}",
-    fixed = TRUE
+    "hidden reserved variables ..\\.log_weight.."
   )
 })
 
@@ -69,8 +83,7 @@ test_that("print.draws_matrix handles reserved variables correctly", {
   expect_output(print(x, max_variables = 1), "tau")
   expect_output(
     print(x),
-    "hidden reserved variables {'.log_weight'}",
-    fixed = TRUE
+    "hidden reserved variables ..\\.log_weight.."
   )
 })
 
@@ -91,18 +104,29 @@ test_that("print.draws_list handles reserved variables correctly", {
   expect_output(print(x, max_variables = 1), "tau")
   expect_output(
     print(x),
-    "hidden reserved variables {'.log_weight'}",
-    fixed = TRUE
+    "hidden reserved variables ..\\.log_weight.."
   )
 })
 
 test_that("print.draws_rvars handles reserved variables correctly", {
+  skip_on_os("windows")
   x <- as_draws_rvars(example_draws())
   variables(x)[1] <- ".log_weight" # reserved name
   expect_output(print(x, max_variables = 1), "tau")
   expect_output(
     print(x),
-    "hidden reserved variables {'.log_weight'}",
-    fixed = TRUE
+    "hidden reserved variables ..\\.log_weight.."
+  )
+})
+
+test_that("print.draws_df correctly handles data frames with unrepaired draws", {
+  x <- as_draws_df(list(x = 1:10, y = 2:11))
+  x_slice <- x[c(1,3,5),]
+  expect_output(
+    print(x_slice),
+"x +y
+1 +1 +2
+2 +3 +4
+3 +5 +6"
   )
 })
